@@ -3,10 +3,10 @@ package RPi::WiringPi::Board;
 use strict;
 use warnings;
 
-use parent 'WiringPi::API';
+use parent 'RPi::WiringPi::Core';
 use RPi::WiringPi::Constant qw(:all);
 
-our $VERSION = '0.99_05';
+our $VERSION = '0.03';
 
 sub new {
     return bless {}, shift;
@@ -14,6 +14,14 @@ sub new {
 sub rev {
     return $_[0]->board_rev;
 }
+sub wpi_to_gpio {
+    my ($self, $pin_num) = @_;
+    return $self->wpi_to_gpio($pin_num);
+}
+sub phys_to_gpio {
+    my ($self, $pin_num) = @_;
+    return $self->phys_to_gpio($pin_num);
+}
 sub pwm_range {
     my ($self, $range) = @_;
     $self->pwm_set_range($range);
@@ -36,7 +44,7 @@ RPi::WiringPi::Board - Access and manipulate Raspberry Pi board attributes
 
     my $board_revision = $board->rev;
 
-    my $pin_num = 5;
+    my $pin_num;
     my $wpi_to_gpio = $board->wpi_to_gpio($pin_num);
     my $phys_to_gpio = $board->phys_to_gpio($pin_num);
 
@@ -63,19 +71,27 @@ Returns a new C<RPi::WiringPi::Board> object.
 
 Returns the revision of the Pi board.
 
-=head2 pwm_range($range)
+=head2 wpi_to_gpio($pin_num)
 
-Changes the range of Pulse Width Modulation (PWM). The default is C<0> through
-C<1024>.
+Converts a pin number from C<wiringPi> notation to Broadcom (BCM) notation,
+and returns the BCM representation.
 
 Parameters:
 
-    $range
+    $pin_num
 
-Mandatory: An integer specifying the high-end of the range. The range always
-starts at C<0>. Eg: if C<$range> is C<359>, if you incremented PWM by C<1>
-every second, you'd rotate a step motor one complete rotation in exactly one
-minute.
+Mandatory: The C<wiringPi> representation of a pin number.
+
+=head2 phys_to_gpio($pin_num)
+
+Converts a pin number as physically documented on the Raspberry Pi board
+itself to Broadcom (BCM) notation, and returns it.
+
+Parameters:
+
+    $pin_num
+
+Mandatory: The pin number printed on the physical Pi board.
 
 =head1 SEE ALSO
 
