@@ -3,16 +3,15 @@ package RPi::WiringPi::Pin;
 use strict;
 use warnings;
 
-use Carp qw(croak);
 use parent 'RPi::WiringPi::Core';
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub new {
     my ($class, $pin) = @_;
 
     if (! defined $pin || ($pin > 40 || $pin < 0)){
-        croak "pin number must be between 0 and 40\n";
+        die "pin number must be between 0 and 40\n";
     }
 
     my $self = bless {}, $class;
@@ -43,7 +42,7 @@ sub pwm {
     my ($self, $value) = @_;
     if ($self->mode != 2){
         my $num = $self->num;
-        croak "\npin $num isn't set to mode 2 (PWM). pwm() can't be set\n";
+        die "\npin $num isn't set to mode 2 (PWM). pwm() can't be set\n";
     }
     $self->pwm_write($self->num, $value);
 }
@@ -61,25 +60,20 @@ RPi::WiringPi::Pin - Access and manipulate Raspberry Pi GPIO pins
 =head1 SYNOPSIS
 
     use RPi::WiringPi;
-    
-    use constant {
-        INPUT => 0,
-        OUTPUT => 1,
-        ON => 1,
-        OFF => 0,
-    };
+    use RPi::Constant qw(:all);
 
     my $pi = RPi::WiringPi->new;
 
     my $pin = $pi->pin(5);
 
     $pin->mode(OUTPUT);
-    $pin->write(ON);
+    $pin->write(HIGH);
 
-    my $pin_num = $pin->num;
-    my $pin_state = $pin->read;
+    my $num = $pin->num;
+    my $mode = $pin->mode;
+    my $state = $pin->read;
 
-    print "pin number $pin_num is in state $pin_state\n";
+    print "pin number $num is in mode $mode with state $state\n";
 
 =head1 DESCRIPTION
 
@@ -101,7 +95,7 @@ Parameters:
 
 Mandatory. 
 
-The L<wiringPi|http://wiringpi.com> representation of a pin number.
+Mandatory: The pin number to attach to.
 
 =head2 mode($mode)
 
@@ -113,8 +107,8 @@ Parameters:
     $mode
 
 Optional: If not sent in, we'll simply return the current mode of the pin.
-Otherwise, send in: C<0> for INPUT, C<1> for OUTPUT, C<2> for PWM and C<3>
-for GPIO_CLK (clock) mode.
+Otherwise, send in: C<0> for INPUT, C<1> for OUTPUT, C<2> for PWM_OUT and C<3>
+for GPIO_CLOCK (clock) mode.
 
 =head2 read()
 
@@ -149,12 +143,11 @@ Parameter:
 
     $value
 
-Mandatory: values range from 0-1024. C<0> for 0% (off) and C<1024> for 100% (fully on).
+Mandatory: values range from 0-1023. C<0> for 0% (off) and C<1023> for 100% (fully on).
 
 =head2 num()
 
-Returns the L<wiringPi|http://wiringPi> numeric representation of the GPIO pin
-number attached to this pin object.
+Returns the pin number associated with the pin object.
 
 =head1 SEE ALSO
 
